==> nextcloud-28.0.3.tgz: nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna poveznica",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Shared by" : "Podijeljeno od",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Go back" : "Natrag",
    "Back to {folder}" : "Natrag na {folder}",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "Home" : "Doma",
    "View" : "Pregledaj",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Add" : "Dodaj",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Details" : "Pojedinosti",
    "Open the \"{name}\" sub-directory" : "Otvori poddirektorij „{name}”",
    "Shared albums" : "Dijeljeni albumi"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-30.0.10.tgz: nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna poveznica",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Shared by" : "Podijeljeno od",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Back to {folder}" : "Natrag na {folder}",
    "Go back" : "Natrag",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "Add folder" : "Dodaj mapu",
    "Home" : "Doma",
    "View" : "Pregledaj",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Details" : "Pojedinosti",
    "Add" : "Dodaj"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
